@@ -16,7 +16,9 @@ class save_mongo:
              db = client['douyu']
              p = db['do']
              p即为collec
-           plex为需要查重的键名  \n
+           plex为需要查重的键名，如若不查重，请赋值为False
+
+           \n
 
             """
         self.data=data
@@ -34,47 +36,52 @@ class save_mongo:
     def save(self):
 
         p=self.collec
-        for i in range(len(self.data)):
-            # 通过主键id查重 不存在插入 存在跳过
-            try:
-                # 查重处理
-                key = p.find_one({"{}".format(self.plex): str(self.data[i]['{}'.format(self.plex)])}, {'{}'.format(self.plex): 1})
-                if key == None:
-                    # print(key == None)
-                    pass
+        if not self.plex:
+            result = p.insert(self.data)
+        else:
+            for i in range(len(self.data)):
+                # 通过主键id查重 不存在插入 存在跳过
+                try:
+                    # 查重处理
+                    key = p.find_one({"{}".format(self.plex): str(self.data[i]['{}'.format(self.plex)])}, {'{}'.format(self.plex): 1})
+                    if key == None:
+                        # print(key == None)
+                        pass
 
-                # do something
-                # key=p
-                # print(key)
-                # 是否有重复数据
-                repetition = key
+                    # 是否有重复数据
+                    repetition = key
+                    # 重复
+                    if repetition:
+                        # print('跳过')
+                        pass
+                    else:
+                        result = p.insert_one(self.data[i])
+                        print(self.data[i])
 
-                # 重复
-                if repetition:
-                    # print('跳过')
-                    pass
+                except Exception as error:
+                    # 出现错误时打印错误日志
+                    print(error, "jieshuyichang")
 
-                else:
-                    result = p.insert_one(self.data[i])
-                    print(self.data[i])
-
-            except Exception as error:
-                # 出现错误时打印错误日志
-                print(error, "jieshuyichang")
-
-    # def select(self):
     # 查重,若存在数据则更新，不存在则插入
     def save_of_dict(self):
         k=[]
+        p = self.collec
         for count in range(len(list(self.data.values())[0])):
             s = {}
 
             for key, values in self.data.items():
                 s[key] = values[count]
             k.append(s)
-        p = self.collec
         # print(k)
-        for i in range(len(k)):
-             p.update_one({'书名': k[i][self.plex]}, {'$set': k[i]},True)
+        if not self.plex:
+
+            # for i in range(len(k)):
+            #     print(k[i])
+            #     p.insert(k)
+            p.insert(k)
+        else:
+            # print(k)
+            for i in range(len(k)):
+                 p.update_one({'{}'.format(self.plex): k[i][self.plex]}, {'$set': k[i]},True)
 
 
